# Welcome to beamgis


[![image](https://img.shields.io/pypi/v/beamgis.svg)](https://pypi.python.org/pypi/beamgis)


**A python package for geospatial analysis and mapping**


-   Free software: MIT License
-   Documentation: <https://eafriyie28.github.io/beamgis>
    

## Features

-   TODO
